.. moffragmentor documentation master file, created by
   sphinx-quickstart on Wed Jan 27 16:27:09 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. figure:: _static/logo.png
   :align: center
   :scale: 80%
   :alt: moffragmentor

Welcome to moffragmentor's documentation!
=========================================

The moffragmentor package gives utilities to interact with reticular building blocks in an object-oriented way.

Contents
---------

.. toctree::
   :maxdepth: 2

   getting_started
   background
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
